@@ -1,7 +1,21 @@
+# -*- coding: utf-8 -*-
+#
+# Copyright (C) 2007-2013 Edgewall Software
+# Copyright (C) 2007 Christian Boos <cboos@edgewall.org>
+# All rights reserved.
+#
+# This software is licensed as described in the file COPYING, which
+# you should have received as part of this distribution. The terms
+# are also available at http://trac.edgewall.com/license.html.
+#
+# This software consists of voluntary contributions made by many
+# individuals. For the exact contribution history, see the revision
+# history and logs, available at http://trac.edgewall.org/.
+
 """Inserts the current time (in seconds) into the wiki page."""
 
-revision = "$Rev: 10617 $"
-url = "$URL: file:///var/svn/trac/tags/trac-1.0/sample-plugins/Timestamp.py $"
+revision = "$Rev: 12743 $"
+url = "$URL: http://svn.edgewall.org/repos/trac/tags/trac-1.0.4/sample-plugins/Timestamp.py $"
 
 #
 # The following shows the code for macro, old-style.
@@ -36,8 +50,8 @@ from trac.wiki.macros import WikiMacroBase
 class TimestampMacro(WikiMacroBase):
     _description = "Inserts the current time (in seconds) into the wiki page."
 
-    def expand_macro(self, formatter, name, args):
+    def expand_macro(self, formatter, name, content, args=None):
         t = datetime.now(utc)
-        return tag.b(format_datetime(t, '%c'))
+        return tag.strong(format_datetime(t, '%c'))
 # --
 # ---- (reuse for your own macro) ----
